@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Stephen Leaf                                    *
- *   smileaf@smileaf.org                                                   *
+ *   Copyright (C) 2005-2007 by Stephen Leaf <smileaf@gmail.com>           *
+ *   Copyright (C) 2006 by Oswald Buddenhagen <ossi@kde.org>               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,56 +18,56 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-
 #ifndef _KDMTHEME_H_
 #define _KDMTHEME_H_
 
+#include <kconfig.h>
 #include <kcmodule.h>
-#include <kaboutdata.h>
-#include <qmap.h>
-#include <klistview.h>
 
-class kdmtheme: public KCModule
-{
+#include <qwidget.h>
+
+class ThemeData;
+
+class QLabel;
+class QPushButton;
+class QListView;
+class QCheckBox;
+
+class KDMThemeWidget : public KCModule {
 	Q_OBJECT
 
-public:
-	kdmtheme( QWidget *parent=0, const char *name=0, const QStringList& = QStringList() );
-	~kdmtheme();
+  public:
+	KDMThemeWidget( QWidget *parent = 0, const char *name=0, const QStringList& = QStringList() );
 
-	virtual void load();
-	virtual void save();
-	virtual void defaults();
-	virtual int buttons();
-	virtual QString quickHelp() const;
-	virtual const KAboutData *aboutData()const
-	{ return p_myAboutData; };
-	virtual QStringList findThemeDirs(const QString &archiveName);
-	virtual QStringList installThemes(QStringList &themes, const QString &archiveName);
-	virtual bool populateList (const QString &themeDir, QStringList &tmpTheme, const QString &themeActiveName);
+	void load();
+	void save();
+	void defaults();
+	void setReadOnly( bool );
 
-public slots:
-    void configChanged();
-	void installNewTheme();
-	void insertTheme(QString theme);
-	void removeSelectedTheme();
-	void themeSelected(QListViewItem *);
+  private:
+	void selectTheme( const QString & );
+	void insertTheme( const QString & );
+	void updateInfoView( ThemeData * );
+
+	QListView *themeWidget;
+	QLabel *preview;
+	QLabel *info;
+	QPushButton *bInstallTheme;
+	QPushButton *bRemoveTheme;
+	QCheckBox *cUseTheme;
+
+	ThemeData *defaultTheme;
+	QString themeDir;
+	KConfig *config;
+signals:
+	void changed();
+
+  protected slots:
 	void themeSelected();
-	void updateTheme(const QString &screenshot, const QString &copyright, const QString &description);
+	void removeSelectedThemes();
+	void installNewTheme();
 	void toggleUseTheme(bool);
 
-private:
-	void insertItem( const QString &_theme, const QString &_activeName = QString::null );
-	void removeTheme( const QString &theme );
-
-	KDMThemeConfig *p_configWidget;
-	KAboutData *p_myAboutData;
-	KSimpleConfig *config;
-	QListViewItem *m_defaultTheme;
-	QListViewItem *m_selectedTheme;
-	QMap <QString, QString>m_themeNames;
-	QStringList themes;
-	QString themeDir;
 };
 
 #endif
